@@ -29,6 +29,8 @@ void Debug(char *fmt,...);
 GtkTooltips *MakeToolTip(void);
 GdkColor *MakeColor(int red,int green,int blue);
 GtkStyle *MakeStyle(GdkColor *fg,GdkColor *bg,gboolean do_grade);
+GtkWidget *BuildMenuItemXpm(GtkWidget *xpm, gchar *text);
+GtkWidget *BuildMenuItem(gchar *impath, gchar *text, gboolean stock);
 GtkWidget *NewBlankPixmap(GtkWidget *widget);
 GtkWidget *ImageButton(GtkWidget *widget,GtkWidget *image);
 GtkWidget *Loadxpm(GtkWidget *widget,char **xpm);
