@@ -32,10 +32,15 @@ typedef struct _ripper {
 typedef struct _mp3_encoder {
   char name[20];
   char cmdline[256];
+  char extension[10];
 } MP3Encoder;
 
 
 void MakeConfigPage(GripInfo *ginfo);
+gboolean LoadRipperConfig(GripInfo *ginfo,int ripcfg);
+void SaveRipperConfig(GripInfo *ginfo,int ripcfg);
+gboolean LoadEncoderConfig(GripInfo *ginfo,int encodecfg);
+void SaveEncoderConfig(GripInfo *ginfo,int encodecfg);
 char *FindExe(char *exename,char **paths);
 void FindExeInPath(char *exename, char *buf, int bsize);
 gboolean FileExists(char *filename);
